Model Code:

.. literalinclude:: /../../cis_interface/examples/gs_lesson4b/src/gs_lesson4b_modelA.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/gs_lesson4b/src/gs_lesson4b_modelB.py
   :language: python
   :linenos:


(`Example in other languages <examples/gs_lesson4b.html>`__)
